soft_saas_ui/components/button library

Soft SaaS UI Button Components

This file implements all button variants from the Soft SaaS UI design system:

  • SoftSaaSButton: Main button component (Primary, Secondary, Tertiary, Outline, Ghost, Destructive)
  • SoftSaaSIconButton: Icon-only button variant

All buttons feature neumorphic shadows, smooth transitions, and full dark mode support.

Classes

ButtonColors
Internal class for button color configuration
SoftSaaSButton
Soft SaaS UI Button Component
SoftSaaSIconButton
Icon-only button component

Enums

IconPosition
Icon position relative to button text
SoftSaaSButtonSize
Button size variants
SoftSaaSButtonVariant
Button variant types
SoftSaaSIconButtonVariant
Icon button variants