SoftSaaSIconButtonVariant enum
Icon button variants
Values
- ghost → const SoftSaaSIconButtonVariant
-
Ghost - transparent, shows background on hover
- elevated → const SoftSaaSIconButtonVariant
-
Elevated - has background and shadow
- primary → const SoftSaaSIconButtonVariant
-
Primary color icon
- destructive → const SoftSaaSIconButtonVariant
-
Destructive/error color icon
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SoftSaaSIconButtonVariant> - A constant List of the values in this enum, in order of their declaration.