SelectOption class

Select option

Constructors

SelectOption({required String value, required String label, bool disabled = false, Widget? leading, TextStyle? labelStyle})
const

Properties

disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
labelStyle TextStyle?
Optional style override for this option's label text.
final
leading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited