labelStyle property
Optional style override for this option's label text.
Applied via TextStyle.merge over the default style, so only the fields you specify (e.g. TextStyle.fontWeight) are overridden.
Implementation
final TextStyle? labelStyle;
Optional style override for this option's label text.
Applied via TextStyle.merge over the default style, so only the fields you specify (e.g. TextStyle.fontWeight) are overridden.
final TextStyle? labelStyle;