soft_saas_ui/theme library
Theme Configuration for Soft SaaS UI
This file combines all design tokens, typography, and shadows into a complete Flutter ThemeData configuration.
Classes
- SoftSaaSTheme
- Soft SaaS UI theme configuration
Theme Configuration for Soft SaaS UI
This file combines all design tokens, typography, and shadows into a complete Flutter ThemeData configuration.