SoftSaaSButtonVariant enum
Button variant types
Values
- primary → const SoftSaaSButtonVariant
-
Primary button - filled with primary color (blue)
- secondary → const SoftSaaSButtonVariant
-
Secondary button - filled with neutral gray
- tertiary → const SoftSaaSButtonVariant
-
Tertiary button - filled with lighter gray
- outline → const SoftSaaSButtonVariant
-
Outline button - transparent with border
- ghost → const SoftSaaSButtonVariant
-
Ghost button - transparent, no border
- destructive → const SoftSaaSButtonVariant
-
Destructive button - filled with error/red color
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SoftSaaSButtonVariant> - A constant List of the values in this enum, in order of their declaration.